@@ -740,13 +740,11 @@ class Upgrade extends Installer {
 
 		$submissionDao = DAORegistry::getDAO('SubmissionDAO'); /* @var $submissionDao SubmissionDAO */
 		$result = $submissionDao->retrieve(
-			'SELECT
-				ps.submission_id as submission_id,
+			'SELECT	ps.submission_id as submission_id,
 				ps.cover_image as cover_image,
 				s.context_id as context_id
-			FROM published_submissions ps
-			LEFT JOIN submissions s ON (s.submission_id = ps.submission_id)
-			GROUP BY submission_id'
+			FROM	published_submissions ps
+			LEFT JOIN	submissions s ON (s.submission_id = ps.submission_id)'
 		);
 		while (!$result->EOF) {
 			$row = $result->getRowAssoc(false);
@@ -759,8 +757,9 @@ class Upgrade extends Installer {
 				$result->MoveNext();
 				continue;
 			}
-			if (empty($contexts[$row['context_id']])) {
-				$contexts[$row['context_id']] = Services::get('context')->get($row['context_id']);
+			$context = $contexts[$row['context_id']];
+			if (empty($context)) {
+				$context = Services::get('context')->get($row['context_id']);
 			}
 
 			// Get existing image paths
@@ -796,29 +795,27 @@ class Upgrade extends Installer {
 			);
 
 			// Create a submission_settings entry for each locale
-			foreach ($contexts[$row['context_id']]->getSupportedFormLocales() as $localeKey) {
-				$newCoverPathInfo = pathinfo($newCoverPath);
-				$submissionDao = DAORegistry::getDAO('SubmissionDAO'); /* @var $submissionDao SubmissionDAO */
-				$submissionDao->update(
-					'INSERT INTO submission_settings
-						SET
-							submission_id = ?,
-							setting_name = ?,
-							setting_value = ?,
-							locale = ?,
-							setting_type= ?',
-					[
-						$row['submission_id'],
-						'coverImage',
-						serialize([
-							'uploadName' => $newCoverPathInfo['basename'],
-							'dateUploaded' => $coverImage['dateUploaded'],
-							'altText' => '',
-						]),
-						$localeKey,
-						'string',
-					]
-				);
+			if(isset($context)) {
+				foreach ($context->getSupportedFormLocales() as $localeKey) {
+					$newCoverPathInfo = pathinfo($newCoverPath);
+					$submissionDao = DAORegistry::getDAO('SubmissionDAO');
+					/* @var $submissionDao SubmissionDAO */
+					$submissionDao->update(
+						'INSERT INTO submission_settings (submission_id, setting_name, setting_value, setting_type, locale)
+						VALUES (?, ?, ?, ?, ?)',
+						[
+							$row['submission_id'],
+							'coverImage',
+							serialize([
+								'uploadName' => $newCoverPathInfo['basename'],
+								'dateUploaded' => $coverImage['dateUploaded'],
+								'altText' => '',
+							]),
+							'object',
+							$localeKey,
+						]
+					);
+				}
 			}
 
 			// Delete the old images
