@@ -21,7 +21,7 @@ use \DAORegistry;
 use \Services;
 use \PKP\Services\interfaces\EntityPropertyInterface;
 use \PKP\Services\interfaces\EntityReadInterface;
-use \APP\Services\QueryBuilders\UserQueryBuilder;
+use \PKP\Services\QueryBuilders\PKPUserQueryBuilder;
 
 class PKPUserService implements EntityPropertyInterface, EntityReadInterface {
 
@@ -118,7 +118,7 @@ class PKPUserService implements EntityPropertyInterface, EntityReadInterface {
 
 		$args = array_merge($defaultArgs, $args);
 
-		$userListQB = new UserQueryBuilder();
+		$userListQB = new PKPUserQueryBuilder();
 		$userListQB
 			->filterByContext($args['contextId'])
 			->orderBy($args['orderBy'], $args['orderDirection'])
@@ -139,6 +139,14 @@ class PKPUserService implements EntityPropertyInterface, EntityReadInterface {
 			$userListQB->offsetBy($args['count']);
 		}
 
+		if (isset($args['assignedToSection'])) {
+			$userListQB->assignedToSection($args['assignedToSection']);
+		}
+
+		if (isset($args['assignedToCategory'])) {
+			$userListQB->assignedToCategory($args['assignedToCategory']);
+		}
+
 		\HookRegistry::call('User::getMany::queryBuilder', array($userListQB, $args));
 
 		return $userListQB;
